@@ -271,8 +271,7 @@ Related object: L<Interchange6::Schema::Result::UserRole>
 
 has_many
   user_roles => "Interchange6::Schema::Result::UserRole",
-  "users_id",
-  { cascade_copy => 0, cascade_delete => 0 };
+  "users_id";
 
 =head2 roles
 
@@ -288,25 +287,25 @@ many_to_many roles => "user_roles", "role";
 
 Type: has_many
 
-Related object: L<Interchange6::Schema::Result::Message> FK C<approved_by>
+Related object: L<Interchange6::Schema::Result::Message> FK C<approved_by_users_id>
 
 =cut
 
 has_many
   approvals => "Interchange6::Schema::Result::Message",
-  { 'foreign.approved_by' => 'self.users_id' };
+  { 'foreign.approved_by_users_id' => 'self.users_id' };
 
 =head2 messages
 
 Type: has_many
 
-Related object: L<Interchange6::Schema::Result::Message> FK C<author>
+Related object: L<Interchange6::Schema::Result::Message> FK C<author_users_id>
 
 =cut
 
 has_many
   messages => "Interchange6::Schema::Result::Message",
-  { 'foreign.author' => 'self.users_id' };
+  { 'foreign.author_users_id' => 'self.users_id' };
 
 =head1 METHODS
 
@@ -331,6 +330,35 @@ sub new {
     return $new;
 }
 
+=head2 insert
+
+Overloaded method. Always add new users to Role with name 'user'.
+
+=cut
+
+sub insert {
+    my ($self, @args) = @_;
+    
+    my $guard = $self->result_source->schema->txn_scope_guard;
+
+    $self->next::method(@args);
+
+    my $user_role = $self->result_source->schema->resultset('Role')
+      ->find( { name => 'user' } );
+
+    if ( $user_role ) {
+        $self->create_related( 'user_roles', { roles_id => $user_role->id } );
+    }
+    else {
+        # we should never get here
+        $self->throw_exception(
+            "Role with name 'user' must exist when creating a new user");
+    }
+    
+    $guard->commit;
+    return $self;
+}
+
 =head2 update
 
 Overloaded method. Throw exception if username is undef, empty string or not lowercase.
@@ -380,6 +408,17 @@ sub blog_posts {
     return $self->messages->search( { type => 'blog_post' } );
 }
 
+=head2 name
+
+Returns L</first_name> and L</last_name> joined by a single space.
+
+=cut
+
+sub name {
+    my $self = shift;
+    return $self->first_name . " " . $self->last_name;
+}
+
 =head2 reviews
 
 Returns resultset of messages that are reviews (referenced by ProductReview class).
