@@ -275,8 +275,8 @@ test 'pricing tests' => sub {
             discount_percent  => undef,
             inventory         => undef,
             name              => "Disposable Brush Set",
-            price             => 14.99,
-            selling_price     => undef,
+            price             => num(14.99, 0.01),
+            selling_price     => num(14.99, 0.01),
             short_description => "Disposable Brush Set",
             sku               => "os28007",
             uri               => "disposable-brush-set"
@@ -285,8 +285,8 @@ test 'pricing tests' => sub {
             discount_percent  => 16,
             inventory         => undef,
             name              => "Painters Brush Set",
-            price             => 29.99,
-            selling_price     => 24.99,
+            price             => num(29.99, 0.01),
+            selling_price     => num(24.99, 0.01),
             short_description => "Painters Brush Set",
             sku               => "os28006",
             uri               => "painters-brush-set"
@@ -295,8 +295,8 @@ test 'pricing tests' => sub {
             discount_percent  => undef,
             inventory         => undef,
             name              => "Trim Brush",
-            price             => 8.99,
-            selling_price     => undef,
+            price             => num(8.99, 0.01),
+            selling_price     => num(8.99, 0.01),
             short_description => "Trim Brush",
             sku               => "os28005",
             uri               => "trim-brush"
@@ -324,8 +324,8 @@ test 'pricing tests' => sub {
             discount_percent  => undef,
             inventory         => undef,
             name              => "Disposable Brush Set",
-            price             => 14.99,
-            selling_price     => undef,
+            price             => num(14.99, 0.01),
+            selling_price     => num(14.99, 0.01),
             short_description => "Disposable Brush Set",
             sku               => "os28007",
             uri               => "disposable-brush-set"
@@ -334,8 +334,8 @@ test 'pricing tests' => sub {
             discount_percent  => 16,
             inventory         => undef,
             name              => "Painters Brush Set",
-            price             => 29.99,
-            selling_price     => 24.99,
+            price             => num(29.99, 0.01),
+            selling_price     => num(24.99, 0.01),
             short_description => "Painters Brush Set",
             sku               => "os28006",
             uri               => "painters-brush-set"
@@ -363,8 +363,8 @@ test 'pricing tests' => sub {
             discount_percent  => undef,
             inventory         => undef,
             name              => "Trim Brush",
-            price             => 8.99,
-            selling_price     => undef,
+            price             => num(8.99, 0.01),
+            selling_price     => num(8.99, 0.01),
             short_description => "Trim Brush",
             sku               => "os28005",
             uri               => "trim-brush"
@@ -388,8 +388,8 @@ test 'pricing tests' => sub {
             discount_percent  => undef,
             inventory         => undef,
             name              => "Disposable Brush Set",
-            price             => 14.99,
-            selling_price     => undef,
+            price             => num(14.99, 0.01),
+            selling_price     => num(14.99, 0.01),
             short_description => "Disposable Brush Set",
             sku               => "os28007",
             uri               => "disposable-brush-set"
@@ -398,8 +398,8 @@ test 'pricing tests' => sub {
             discount_percent  => 16,
             inventory         => undef,
             name              => "Painters Brush Set",
-            price             => 29.99,
-            selling_price     => 24.99,
+            price             => num(29.99, 0.01),
+            selling_price     => num(24.99, 0.01),
             short_description => "Painters Brush Set",
             sku               => "os28006",
             uri               => "painters-brush-set"
@@ -408,8 +408,8 @@ test 'pricing tests' => sub {
             discount_percent  => 5,
             inventory         => undef,
             name              => "Trim Brush",
-            price             => 8.99,
-            selling_price     => 8.49,
+            price             => num(8.99, 0.01),
+            selling_price     => num(8.49, 0.01),
             short_description => "Trim Brush",
             sku               => "os28005",
             uri               => "trim-brush"
@@ -433,7 +433,7 @@ test 'pricing tests' => sub {
     );
 
     $expected->[2]->{discount_percent} = undef;
-    $expected->[2]->{selling_price} = undef;
+    $expected->[2]->{selling_price} = num(8.99, 0.01);
 
     cmp_deeply( \@products, $expected, "do we have expected products?" );
 
@@ -451,7 +451,7 @@ test 'pricing tests' => sub {
 
     # we might get this with or without trailing zero depending on
     # database engine we're testing against
-    $expected->[2]->{selling_price} = any(qw/8.20 8.2/);
+    $expected->[2]->{selling_price} = num(8.20, 0.01);
     $expected->[2]->{discount_percent} = 8;
 
     cmp_deeply( \@products, $expected, "do we have expected products?" );
